@@ -1,5 +1,5 @@
-from protowhat.utils_messaging import get_ord
-from pythonwhat.tasks import (
+from tcs_protowhat.utils_messaging import get_ord
+from tcs_pythonwhat.tasks import (
     getResultInProcess,
     getOutputInProcess,
     getErrorInProcess,
@@ -8,10 +8,10 @@ from pythonwhat.tasks import (
     getOptionFromProcess,
     UndefinedValue,
 )
-from pythonwhat.Test import EqualTest, DefinedCollTest
-from protowhat.Feedback import Feedback, FeedbackComponent
-from protowhat.failure import InstructorError, debugger
-from pythonwhat import utils
+from tcs_pythonwhat.Test import EqualTest, DefinedCollTest
+from tcs_protowhat.Feedback import Feedback, FeedbackComponent
+from tcs_protowhat.failure import InstructorError, debugger
+from tcs_pythonwhat import utils
 from functools import partial
 import re
 import copy
@@ -313,12 +313,12 @@ def has_expr(
 
         if (test == "error") ^ isinstance(eval_sol, Exception):
             raise InstructorError.from_message(
-                "Evaluating expression raised error in solution process (or didn't raise if testing for one). "
-                "Error: {} - {}".format(type(eval_sol), str_sol)
+                "Выполнение выражения solution-кода вызвало ошибку (или не вызвала, если тестирование проводилось для одного). "
+                "Ошибка: {} - {}".format(type(eval_sol), str_sol)
             )
         if isinstance(eval_sol, ReprFail):
             raise InstructorError.from_message(
-                "Couldn't extract the value for the highlighted expression from the solution process: "
+                "Не удалось извлечь значение для выделенного выражения из solution-кода:"
                 + eval_sol.info
             )
 
@@ -440,7 +440,7 @@ has_equal_error.__doc__ = """Run targeted student and solution code, and compare
 
 ## Various has tests ----------------------------------------------------------
 
-from pythonwhat.Test import StringContainsTest
+from tcs_pythonwhat.Test import StringContainsTest
 
 
 def has_code(state, text, pattern=True, not_typed_msg=None):
@@ -685,7 +685,7 @@ def has_printout(
 
     """
 
-    extra_msg = "If you want to check printouts done in e.g. a for loop, you have to use a `check_function('print')` chain instead."
+    extra_msg = "Если вы хотетите проверить вывод данных внутри цикла, то вы должны использовать выражение`check_function('print')`."
     state.assert_execution_root("has_printout", extra_msg=extra_msg)
 
     if not_printed_msg is None:
